pub struct TrackerBinding {
pub definition_rev: String,
pub content_rev: Option<String>,
}Expand description
Which content revision of a tracker this instance is bound to.
Fields
definition_rev: Stringcontent_rev: Option<String>None when the tracker is bound but no content has been captured yet.