pub enum HookDetail {
Ran {
command: String,
ok: bool,
log: Utf8PathBuf,
},
WouldRun(String),
SkippedOwnership,
NoHook,
SkippedUnresolved {
command: String,
placeholder: String,
},
}Variants
Ran
WouldRun(String)
Would have run, but this was a dry run.
SkippedOwnership
project or user ownership: shared beyond this instance.
NoHook
No [cleanup] command defined.
SkippedUnresolved
The hook’s command still had an unresolved {{...}}, so running it
would have passed a literal placeholder to a destructive command.