pub struct ExportedFile {
pub path: Utf8PathBuf,
pub reason: Reason,
pub tracker: Option<String>,
}Fields
path: Utf8PathBufWorkspace-relative path, which is also its path in the export.
reason: Reasontracker: Option<String>The tracker that owns it, for anything but plain source.