pub struct AddResourceOutcome {
pub path: Utf8PathBuf,
pub companions_created: Vec<Utf8PathBuf>,
pub trackers_created: Vec<Utf8PathBuf>,
}Fields
path: Utf8PathBufcompanions_created: Vec<Utf8PathBuf>Companion definitions created because the template depends on them.
trackers_created: Vec<Utf8PathBuf>Tracker lanes created because the template deposits into them.