TrackPathsOutcome

Struct TrackPathsOutcome 

pub struct TrackPathsOutcome {
    pub path: Utf8PathBuf,
    pub added_paths: Vec<Utf8PathBuf>,
    pub ignored_patterns: Vec<String>,
    pub seedable: bool,
}

Fields

path: Utf8PathBufadded_paths: Vec<Utf8PathBuf>ignored_patterns: Vec<String>seedable: bool

At least one newly tracked path already has content in the store repo, so the lane can be seeded from it without spawning anything.