pub struct WorkspaceMarker {
pub branch: String,
pub store_root: Utf8PathBuf,
}Expand description
Gitignored marker inside a workspace pointing back at the store, so newgit commands run from inside a workspace find the real metadata and know which instance they are standing in.
Fields
branch: Stringstore_root: Utf8PathBufTrait Implementations
Sourceimpl Clone for WorkspaceMarker
impl Clone for WorkspaceMarker
Sourcefn clone(&self) -> WorkspaceMarker
fn clone(&self) -> WorkspaceMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspaceMarker
impl Debug for WorkspaceMarker
Sourceimpl<'de> Deserialize<'de> for WorkspaceMarker
impl<'de> Deserialize<'de> for WorkspaceMarker
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkspaceMarker
Sourceimpl PartialEq for WorkspaceMarker
impl PartialEq for WorkspaceMarker
Sourceimpl Serialize for WorkspaceMarker
impl Serialize for WorkspaceMarker
impl StructuralPartialEq for WorkspaceMarker