allocate

Function allocate 

pub fn allocate(start: u16, used: &mut BTreeSet<u16>) -> Result<u16>
First port scanning up from start that is neither promised to another instance nor OS-unbindable right now. The chosen port is added to used so one allocation pass stays self-consistent.